@@ -293,11 +293,13 @@ def build_node_and_resolver(
     node_resolver_name = f"{object_type.node_name}Resolver"
     property_strs: T.List[str] = []
     insert_property_strs: T.List[str] = []
+    patch_property_strs: T.List[str] = []
     updatable_fields: T.Set[str] = set()
     exclusive_fields: T.Set[str] = set()
 
     node_edgedb_conversion_map: T.Dict[str, T.Dict[str, str]] = {}
     insert_edgedb_conversion_map: T.Dict[str, T.Dict[str, str]] = {}
+    patch_edgedb_conversion_map: T.Dict[str, T.Dict[str, str]] = {}
 
     computed_properties: T.Set[str] = set()
     computed_property_getter_strs: T.List[str] = []
@@ -372,8 +374,8 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
     self.{property_name} = {prop.name}
                     """
                 )
-        # for insert type
         if prop.name != "id":
+            # for insert type
             if not prop.is_computed and not prop.not_insertable:
                 insert_edgedb_conversion_map[prop.name] = {
                     "cast": conversion_type,
@@ -390,6 +392,21 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
                 insert_property_strs.append(
                     f"{prop.name}: {insert_type_str}{default_value_str}"
                 )
+            # for update type
+            if not prop.is_computed and not prop.readonly:
+                patch_edgedb_conversion_map[prop.name] = {
+                    "cast": conversion_type,
+                    "cardinality": prop.cardinality.value,
+                    "readonly": prop.readonly,
+                }
+                patch_type_str = type_str
+                if prop.required and prop.default:
+                    patch_type_str = f"T.Optional[{patch_type_str}]"
+                final_patch_type_str = f"T.Union[{patch_type_str}, Unset]"
+                patch_property_strs.append(
+                    f"{prop.name}: {final_patch_type_str} = Field(default_factory=Unset)"
+                )
+
     link_function_strs: T.List[str] = []
     resolver_function_strs: T.List[str] = []
     updatable_links: T.Set[str] = set()
@@ -428,6 +445,16 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
             insert_property_strs.append(
                 f"{link.name}: {insert_resolver_str}{default_value_str}"
             )
+        # for update
+        if not link.is_computed and not link.readonly:
+            patch_resolver_str = f"{link.target.model_name}Resolver"
+            if (not link.required) or (link.required and link.default):
+                patch_resolver_str = f"T.Optional[{patch_resolver_str}]"
+            final_patch_resolver_str = f"T.Union[{patch_resolver_str}, Unset]"
+            patch_property_strs.append(
+                f"{link.name}: {final_patch_resolver_str} = Field(default_factory=Unset)"
+            )
+
     orm_config_str = build_orm_config(
         model_name=object_type.node_name,
         updatable_fields={*updatable_fields, *updatable_links},
@@ -435,12 +462,18 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
     )
 
     insert_model_name = f"{object_type.node_name}Insert"
+    patch_model_name = f"{object_type.node_name}Patch"
 
     # insert type
     insert_inner_str = "\n".join(insert_property_strs)
     insert_conversion_map_str = f"_edgedb_conversion_map: T.ClassVar[T.Dict[str, str]] = {stringify_dict(insert_edgedb_conversion_map)}"
     insert_s = f"class {insert_model_name}(BaseModel):\n{indent_lines(insert_inner_str)}\n\n{indent_lines(insert_conversion_map_str)}"
 
+    # patch type
+    patch_inner_str = "\n".join(patch_property_strs)
+    patch_conversion_map_str = f"_edgedb_conversion_map: T.ClassVar[T.Dict[str, str]] = {stringify_dict(patch_edgedb_conversion_map)}"
+    patch_s = f"class {patch_model_name}(BaseModel):\n{indent_lines(patch_inner_str)}\n\n{indent_lines(patch_conversion_map_str)}"
+
     # node
     node_properties_str = "\n".join(property_strs)
     from_str_validator_str = build_from_str_validator_str(node_config=node_config)
@@ -483,7 +516,7 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
     node_outer_strs = []
     node_outer_str = "\n".join(remove_falsies(node_outer_strs))
     inherits = (
-        f"Node[{insert_model_name}]"
+        f"Node[{insert_model_name}, {patch_model_name}]"
         if not hydrate
         else f"{object_type.node_name}Hydrated"
     )
@@ -519,7 +552,7 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
     final_s = (
         f"{object_type.node_name}.{CONFIG_NAME}.resolver_type = {node_resolver_name}"
     )
-    return f"{insert_s}\n{node_s}\n{resolver_s}\n{final_s}"
+    return f"{insert_s}\n{patch_s}\n{node_s}\n{resolver_s}\n{final_s}"
 
 
 async def build_nodes_and_resolvers(
